@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2014 jeanfi@gmail.com
+ * Copyright (C) 2010-2016 jeanfi@gmail.com
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -19,12 +19,26 @@
 #ifndef _PSENSOR_NVIDIA_H_
 #define _PSENSOR_NVIDIA_H_
 
+#include <bool.h>
 #include <psensor.h>
 
-void nvidia_psensor_list_update(struct psensor **sensors);
 
-void nvidia_psensor_list_append(struct psensor ***sensors, int values_length);
+#if defined(HAVE_NVIDIA) && HAVE_NVIDIA
 
-void nvidia_cleanup();
+static inline bool nvidia_is_supported(void) { return true; }
+
+void nvidia_psensor_list_update(struct psensor **);
+void nvidia_psensor_list_append(struct psensor ***, int);
+void nvidia_cleanup(void);
+
+#else
+
+static inline bool nvidia_is_supported(void) { return false; }
+
+static inline void nvidia_psensor_list_update(struct psensor **s) {}
+static inline void nvidia_psensor_list_append(struct psensor ***s, int n) {}
+static inline void nvidia_cleanup(void) {}
+
+#endif
 
 #endif
