@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2014 jeanfi@gmail.com
+ * Copyright (C) 2010-2016 jeanfi@gmail.com
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,7 +21,23 @@
 
 #include <psensor.h>
 
-void udisks2_psensor_list_append(struct psensor ***sensors, int values_length);
-void udisks2_psensor_list_update(struct psensor **sensors);
+#if defined(HAVE_LIBUDISKS2) && HAVE_LIBUDISKS2
+
+static inline bool udisks2_is_supported(void) { return true; }
+
+void udisks2_psensor_list_append(struct psensor ***, int);
+void udisks2_psensor_list_update(struct psensor **);
+
+#else
+
+static inline bool udisks2_is_supported(void) { return false; }
+
+static inline void
+udisks2_psensor_list_append(struct psensor ***s, int n) {}
+
+static inline void
+udisks2_psensor_list_update(struct psensor **s) {}
+
+#endif
 
 #endif
