@@ -38,7 +38,7 @@
 #include "ptime.h"
 #include "slog.h"
 
-static FILE *file;
+static FILE * file;
 static double *last_values;
 static int period;
 static struct psensor **sensors;
@@ -115,10 +115,14 @@ static bool slog_open(const char *path, struct psensor **sensors)
 
 	fprintf(file, "I,%s,%s\n", t, VERSION);
 
-	while (*sensors) {
-		fprintf(file, "S,%s,%x\n", (*sensors)->id,  (*sensors)->type);
-		sensors++;
-	}
+	if (sensors)
+		while (*sensors) {
+			fprintf(file,
+				"S,%s,%x\n",
+				(*sensors)->id,
+				(*sensors)->type);
+			sensors++;
+		}
 
 	fflush(file);
 
