@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2014 jeanfi@gmail.com
+ * Copyright (C) 2010-2016 jeanfi@gmail.com
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -25,7 +25,7 @@
  *  - 0 if psensor is not currently launch during session startup.
  *  - -1 if it cannot be determined.
  */
-int pxdg_is_autostarted();
+int pxdg_is_autostarted(void);
 void pxdg_set_autostart(unsigned int);
 
 #endif
