@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2016 jeanfi@gmail.com
+ * Copyright (C) 2010-2018 jeanfi@gmail.com
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -28,7 +28,7 @@
 #include <ui_sensorpref.h>
 #include <ui_status.h>
 
-static GtkWidget *w_sensors_scrolled_tree;
+static GtkWidget * w_sensors_scrolled_tree;
 static GtkWidget *w_graph;
 static GtkContainer *w_sensor_box;
 static GtkContainer *w_main_box;
@@ -188,14 +188,14 @@ on_delete_event_cb(GtkWidget *widget, GdkEvent *event, gpointer data)
 {
 	struct ui_psensor *ui = data;
 
-	save_window_pos(ui);
-
 	log_debug("is_status_supported: %d\n", is_status_supported());
 
-	if (is_appindicator_supported() || is_status_supported())
+	if (is_appindicator_supported() || is_status_supported()) {
+		save_window_pos(ui);
 		gtk_widget_hide(ui->main_window);
-	else
+	} else {
 		ui_psensor_quit(ui);
+	}
 
 	return TRUE;
 }
@@ -213,7 +213,7 @@ void ui_show_about_dialog(GtkWindow *parent)
 		 _("Psensor is a GTK+ application for monitoring hardware "
 		   "sensors"),
 		 "copyright",
-		 _("Copyright(c) 2010-2016 jeanfi@gmail.com"),
+		 _("Copyright(c) 2010-2020 jeanfi@gmail.com"),
 #if GTK_CHECK_VERSION(3, 12, 0)
 		 "license-type", GTK_LICENSE_GPL_2_0,
 #endif
@@ -343,11 +343,8 @@ void ui_window_create(struct ui_psensor *ui)
 
 	window = GTK_WIDGET(gtk_builder_get_object(builder, "window"));
 	gtk_builder_connect_signals(builder, ui);
+
 	cfg = ui->config;
-	if (cfg->window_restore_enabled)
-		gtk_window_move(GTK_WINDOW(window),
-				cfg->window_x,
-				cfg->window_y);
 
 	config_set_slog_enabled_changed_cbk(slog_enabled_cbk, ui);
 
@@ -401,24 +398,21 @@ void ui_window_create(struct ui_psensor *ui)
 	log_debug("ui_window_create() ends");
 }
 
-void ui_window_update(struct ui_psensor *ui)
+void ui_window_show(struct ui_psensor *ui)
 {
 	struct config *cfg;
 
-	log_debug("ui_window_update()");
+	log_debug("ui_window_show()");
 
 	cfg = ui->config;
-
-	if (cfg->window_restore_enabled)
+	if (cfg->window_restore_enabled) {
 		gtk_paned_set_position(GTK_PANED(w_sensor_box),
 				       cfg->window_divider_pos);
+		gtk_window_move(GTK_WINDOW(ui->main_window),
+				cfg->window_x,
+				cfg->window_y);
+	}
 
-}
-
-void ui_window_show(struct ui_psensor *ui)
-{
-	log_debug("ui_window_show()");
-	ui_window_update(ui);
 	gtk_window_present(GTK_WINDOW(ui->main_window));
 }
 
