@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2014 jeanfi@gmail.com
+ * Copyright (C) 2010-2016 jeanfi@gmail.com
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -23,7 +23,7 @@ static const char *ICON = "psensor_normal";
 static const char *ATTENTION_ICON = "psensor_hot";
 
 static GtkStatusIcon *status;
-static unsigned status_attention;
+static unsigned int status_attention;
 
 static void cb_activate(GtkStatusIcon *icon,
 			gpointer data)
@@ -62,12 +62,12 @@ void ui_status_init(struct ui_psensor *ui)
 			 ui);
 }
 
-int is_status_supported()
+int is_status_supported(void)
 {
 	return status && gtk_status_icon_is_embedded(status);
 }
 
-void ui_status_cleanup()
+void ui_status_cleanup(void)
 {
 	log_debug("ui_status_cleanup()");
 
