@@ -23,7 +23,7 @@
 
 #include "../src/lib/pio.h"
 
-static int test_empty_dir()
+static int test_empty_dir(void)
 {
 	int ret;
 	char **paths;
@@ -38,12 +38,12 @@ static int test_empty_dir()
 		}
 
 		paths_free(paths);
-	} 
+	}
 
 	return ret;
 }
 
-static int test_2files_dir()
+static int test_2files_dir(void)
 {
 	int ret, one, two;
 	char **paths, **cur;
@@ -68,21 +68,21 @@ static int test_2files_dir()
 
 			ret = 1;
 		}
-		
+
 		cur++;
 	}
-	
+
 	if (!ret && one == 1 && two == 1)
 		ret = 0;
 	else
 		ret = 1;
-	
+
 	paths_free(paths);
 
 	return ret;
 }
 
-static int tests_dir_list() {
+static int tests_dir_list(void) {
 	int failures;
 
 	failures = test_empty_dir();
@@ -98,7 +98,7 @@ int main(int argc, char **argv)
 
 	failures = tests_dir_list();
 
-	if (failures) 
+	if (failures)
 		exit(EXIT_FAILURE);
 	else
 		exit(EXIT_SUCCESS);
