@@ -42,7 +42,7 @@ test_fct(unsigned int type, int use_celsius, const char *ref)
 	return 1;
 }
 
-static int test() {
+static int test(void) {
 	int failures;
 
 	failures = 0;
@@ -75,7 +75,7 @@ int main(int argc, char **argv)
 
 	failures = test();
 
-	if (failures) 
+	if (failures)
 		exit(EXIT_FAILURE);
 	else
 		exit(EXIT_SUCCESS);
